@@ -296,7 +296,7 @@ class EwaldSummation(object):
         ereal = np.zeros((numsites, numsites))
         epoint = np.zeros(numsites)
         forces = np.zeros((numsites, 3))
-        for i in xrange(numsites):
+        for i in range(numsites):
             nn = all_nn[i]  # self._s.get_neighbors(site, self._rmax)
             num_neighbors = len(nn)
             qi = self._oxi_states[i]
@@ -316,7 +316,7 @@ class EwaldSummation(object):
                 js[k] = j
                 ncoords[k] = site.coords
 
-            erfcval = np.array(map(erfc, self._sqrt_eta * rij))
+            erfcval = np.array([erfc(k) for k in self._sqrt_eta * rij])
             new_ereals = erfcval * qi * qj / rij
 
             #insert new_ereals
