@@ -16,15 +16,15 @@ import logging
 import itertools
 import numpy as np
 import re
-from collections import defaultdict
 
-from pymatgen.serializers.json_coders import MSONable
+from pymatgen.serializers.json_coders import PMGSONable
 from pymatgen.core.composition import Composition
+from monty.json import MontyDecoder
 
 logger = logging.getLogger(__name__)
 
 
-class BalancedReaction(MSONable):
+class BalancedReaction(PMGSONable):
     """
     An object representing a complete chemical reaction.
     """
@@ -45,7 +45,7 @@ class BalancedReaction(MSONable):
         all_products = sum([k * v for k, v in products_coeffs.items()],
                            Composition({}))
 
-        if not all_reactants.almost_equals(all_products, 
+        if not all_reactants.almost_equals(all_products,
                                 atol=Reaction.TOLERANCE):
             raise ReactionError("Reaction is unbalanced!")
 
@@ -58,9 +58,8 @@ class BalancedReaction(MSONable):
         self._coeffs = []
         self._els = []
         self._all_comp = []
-        for c in set(reactants_coeffs.keys() +
-                                  products_coeffs.keys()):
-
+        for c in set(list(reactants_coeffs.keys()) +
+                list(products_coeffs.keys())):
             coeff = products_coeffs.get(c,0) - \
                                     reactants_coeffs.get(c,0)
 
@@ -111,7 +110,7 @@ class BalancedReaction(MSONable):
         all_comp = self._all_comp
         coeffs = self._coeffs
         current_el_amount = sum([all_comp[i][element] * abs(coeffs[i])
-                                 for i in xrange(len(all_comp))]) / 2
+                                 for i in range(len(all_comp))]) / 2
         scale_factor = factor / current_el_amount
         self._coeffs = [c * scale_factor for c in coeffs]
 
@@ -126,7 +125,7 @@ class BalancedReaction(MSONable):
             Amount of that element in the reaction.
         """
         return sum([self._all_comp[i][element] * abs(self._coeffs[i])
-                    for i in xrange(len(self._all_comp))]) / 2
+                    for i in range(len(self._all_comp))]) / 2
 
     @property
     def elements(self):
@@ -154,7 +153,7 @@ class BalancedReaction(MSONable):
         """
         List of reactants
         """
-        return [self._all_comp[i] for i in xrange(len(self._all_comp))
+        return [self._all_comp[i] for i in range(len(self._all_comp))
                 if self._coeffs[i] < 0]
 
     @property
@@ -162,7 +161,7 @@ class BalancedReaction(MSONable):
         """
         List of products
         """
-        return [self._all_comp[i] for i in xrange(len(self._all_comp))
+        return [self._all_comp[i] for i in range(len(self._all_comp))
                 if self._coeffs[i] > 0]
 
     def get_coeff(self, comp):
@@ -252,8 +251,7 @@ class BalancedReaction(MSONable):
                                                       comp.reduced_formula))
         return " + ".join(reactant_str) + " -> " + " + ".join(product_str)
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         return {"@module": self.__class__.__module__,
                 "@class": self.__class__.__name__,
                 "reactants": {str(comp): coeff
@@ -370,18 +368,18 @@ class Reaction(BalancedReaction):
                     for perm_matrix in itertools.permutations(comp_matrix):
                         logger.debug("Testing permuted matrix = {}"
                                      .format(perm_matrix))
-                        for m in xrange(nconstraints):
+                        for m in range(nconstraints):
                             submatrix = [[perm_matrix[i][j]
-                                          for j in xrange(nconstraints)
+                                          for j in range(nconstraints)
                                           if j != m]
-                                         for i in xrange(nconstraints)
+                                         for i in range(nconstraints)
                                          if i != m]
                             logger.debug("Testing submatrix = {}"
                                          .format(submatrix))
                             if abs(np.linalg.det(submatrix)) > self.TOLERANCE:
                                 logger.debug("Possible sol")
                                 ansmatrix = [perm_matrix[i][m]
-                                             for i in xrange(nconstraints)
+                                             for i in range(nconstraints)
                                              if i != m]
                                 coeffs = -np.linalg.solve(submatrix, ansmatrix)
                                 coeffs = [c for c in coeffs]
@@ -399,7 +397,7 @@ class Reaction(BalancedReaction):
                     raise ReactionError("Reaction is ill-formed and cannot be"
                                         " balanced.")
 
-        for i in xrange(len(coeffs) - 1, -1, -1):
+        for i in range(len(coeffs) - 1, -1, -1):
             if coeffs[i] != 0:
                 normfactor = coeffs[i]
                 break
@@ -416,12 +414,11 @@ class Reaction(BalancedReaction):
         """
         return Reaction(self.reactants, self.products)
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         return {"@module": self.__class__.__module__,
                 "@class": self.__class__.__name__,
-                "reactants": [comp.to_dict for comp in self._input_reactants],
-                "products": [comp.to_dict for comp in self._input_products]}
+                "reactants": [comp.as_dict() for comp in self._input_reactants],
+                "products": [comp.as_dict() for comp in self._input_products]}
 
     @classmethod
     def from_dict(cls, d):
@@ -490,26 +487,23 @@ class ComputedReaction(Reaction):
     def calculated_reaction_energy(self):
         calc_energies = {}
 
-        def update_calc_energies(entry):
+        for entry in self._reactant_entries + self._product_entries:
             (comp, factor) = \
                 entry.composition.get_reduced_composition_and_factor()
             calc_energies[comp] = min(calc_energies.get(comp, float('inf')),
                                       entry.energy / factor)
-        map(update_calc_energies, self._reactant_entries)
-        map(update_calc_energies, self._product_entries)
+
         return self.calculate_energy(calc_energies)
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         return {"@module": self.__class__.__module__,
                 "@class": self.__class__.__name__,
-                "reactants": [e.to_dict for e in self._reactant_entries],
-                "products": [e.to_dict for e in self._product_entries]}
+                "reactants": [e.as_dict() for e in self._reactant_entries],
+                "products": [e.as_dict() for e in self._product_entries]}
 
     @classmethod
     def from_dict(cls, d):
-        from pymatgen.serializers.json_coders import PMGJSONDecoder
-        dec = PMGJSONDecoder()
+        dec = MontyDecoder()
         reactants = [dec.process_decoded(e) for e in d["reactants"]]
         products = [dec.process_decoded(e) for e in d["products"]]
         return cls(reactants, products)
