@@ -13,6 +13,8 @@ Bader decomposition of charge density", Comput. Mater. Sci. 36, 254-360 (2006).
 """
 
 from __future__ import division
+from six.moves import map
+from six.moves import zip
 
 __author__ = "shyuepingong"
 __version__ = "0.1"
@@ -169,6 +171,6 @@ class BaderAnalysis(object):
             to be supplied.
         """
         structure = self.chgcar.structure
-        charges = map(self.get_charge_transfer, xrange(len(structure)))
+        charges = [self.get_charge_transfer(i) for i in range(len(structure))]
         structure.add_oxidation_state_by_site(charges)
         return structure
