@@ -3,6 +3,8 @@ This module defines the classes relating to 3D lattices.
 """
 
 from __future__ import division
+from six.moves import map
+from six.moves import zip
 
 __author__ = "Shyue Ping Ong, Michael Kocher"
 __copyright__ = "Copyright 2011, The Materials Project"
@@ -19,10 +21,12 @@ import numpy as np
 from numpy.linalg import inv
 from numpy import pi, dot, transpose, radians
 
-from pymatgen.serializers.json_coders import MSONable
+from pyhull.voronoi import VoronoiTess
+
+from pymatgen.serializers.json_coders import PMGSONable
 
 
-class Lattice(MSONable):
+class Lattice(PMGSONable):
     """
     A lattice object.  Essentially a matrix with conversion matrices. In
     general, it is assumed that length units are in Angstroms and angles are in
@@ -49,7 +53,7 @@ class Lattice(MSONable):
         m = np.array(matrix, dtype=np.float64).reshape((3, 3))
         lengths = np.sqrt(np.sum(m ** 2, axis=1))
         angles = np.zeros(3)
-        for i in xrange(3):
+        for i in range(3):
             j = (i + 1) % 3
             k = (i + 2) % 3
             angles[i] = dot(m[j], m[k]) / (lengths[j] * lengths[k])
@@ -337,10 +341,8 @@ class Lattice(MSONable):
         try:
             return self._reciprocal_lattice
         except AttributeError:
-            v = [np.cross(self._matrix[(i + 1) % 3], self._matrix[(i + 2) % 3])
-                for i in xrange(3)]
-            self._reciprocal_lattice = Lattice(np.array(v) * 2 * np.pi /
-                                               self.volume)
+            v = np.linalg.inv(self._matrix).T
+            self._reciprocal_lattice = Lattice(v * 2 * np.pi)
             return self._reciprocal_lattice
 
     @property
@@ -380,8 +382,7 @@ class Lattice(MSONable):
         return "\n".join([" ".join(["%.6f" % i for i in row])
                           for row in self._matrix])
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         """""
         Json-serialization dict representation of the Lattice.
         """
@@ -452,7 +453,7 @@ class Lattice(MSONable):
             for c, f in zip(c_cand[2][inds], f_cand[2][inds]):
                 aligned_m = np.array([c_cand[0][i], c_cand[1][j], c])
                 scale_m = np.array([f_cand[0][i], f_cand[1][j], f])
-                if np.abs(np.linalg.det(scale_m)) < 1e-8:
+                if abs(np.linalg.det(scale_m)) < 1e-8:
                     continue
                 rotation_m = np.linalg.solve(aligned_m, other_lattice.matrix)
                 yield Lattice(aligned_m), rotation_m, scale_m
@@ -569,7 +570,7 @@ class Lattice(MSONable):
 
         b[:, 0] = a[:, 0]
         m[0] = dot(b[:, 0], b[:, 0])
-        for i in xrange(1, 3):
+        for i in range(1, 3):
             u[i, 0:i] = dot(a[:, i].T, b[:, 0:i]) / m[0:i]
             b[:, i] = a[:, i] - dot(b[:, 0:i], u[i, 0:i].T)
             m[i] = dot(b[:, i], b[:, i])
@@ -578,7 +579,7 @@ class Lattice(MSONable):
 
         while k <= 3:
             # Size reduction.
-            for i in xrange(k - 1, 0, -1):
+            for i in range(k - 1, 0, -1):
                 q = round(u[k - 1, i - 1])
                 if q != 0:
                     # Reduce the k-th basis vector.
@@ -601,7 +602,7 @@ class Lattice(MSONable):
                 a[:, k - 1] = a[:, k - 2].copy()
                 a[:, k - 2] = v
                 #Update the Gram-Schmidt coefficients
-                for s in xrange(k - 1, k + 1):
+                for s in range(k - 1, k + 1):
                     u[s - 1, 0:(s - 1)] = dot(a[:, s - 1].T,
                                               b[:, 0:(s - 1)]) / m[0:(s - 1)]
                     b[:, s - 1] = a[:, s - 1] - dot(b[:, 0:(s - 1)],
@@ -645,7 +646,7 @@ class Lattice(MSONable):
         G = np.array(G)
 
         #This sets an upper limit on the number of iterations.
-        for count in xrange(100):
+        for count in range(100):
             #The steps are labelled as Ax as per the labelling scheme in the
             #paper.
             (A, B, C, E, N, Y) = (G[0, 0], G[1, 1], G[2, 2],
@@ -773,7 +774,6 @@ class Lattice(MSONable):
             Wigner Seitz cell. For instance, a list of four coordinates will
             represent a square facet.
         """
-        from pyhull.voronoi import VoronoiTess
         vec1 = self.matrix[0]
         vec2 = self.matrix[1]
         vec3 = self.matrix[2]
@@ -884,7 +884,7 @@ class Lattice(MSONable):
         n = len(frac_points)
         fcoords = np.array(frac_points)
         pts = np.tile(center, (n, 1))
-        indices = np.array(range(n))
+        indices = np.array(list(range(n)))
 
         arange = np.arange(start=int(floor(pcoords[0] - nmax[0])),
                            stop=int(floor(pcoords[0] + nmax[0])) + 1)
@@ -906,9 +906,8 @@ class Lattice(MSONable):
                                axis=4))
         within_r = np.where(dists <= r)
 
-        d = [shifted_coords[within_r], dists[within_r], indices[within_r[0]]]
-
-        return np.transpose(d)
+        return list(zip(shifted_coords[within_r], dists[within_r],
+                        indices[within_r[0]]))
 
     def get_all_distances(self, fcoords1, fcoords2):
         """
@@ -949,7 +948,7 @@ class Lattice(MSONable):
 
         cart_f1 = self.get_cartesian_coords(fcoords1)
         cart_f2 = self.get_cartesian_coords(shifted_f2)
-        
+
         if cart_f1.size * cart_f2.size < 1e5:
             #all vectors from f1 to f2
             vectors = cart_f2[None, :, :, :] - cart_f1[:, None, None, :]
@@ -967,9 +966,9 @@ class Lattice(MSONable):
 
     def is_hexagonal(self, hex_angle_tol=5, hex_length_tol=0.01):
         lengths, angles = self.lengths_and_angles
-        right_angles = [i for i in xrange(3)
+        right_angles = [i for i in range(3)
                         if abs(angles[i] - 90) < hex_angle_tol]
-        hex_angles = [i for i in xrange(3)
+        hex_angles = [i for i in range(3)
                       if abs(angles[i] - 60) < hex_angle_tol or
                          abs(angles[i] - 120) < hex_angle_tol]
 
