@@ -13,10 +13,12 @@ __date__ = "Mar 20, 2012"
 
 import numpy as np
 
+import six
+
 from pymatgen.electronic_structure.core import Spin, Orbital
 from pymatgen.core.structure import Structure
 from pymatgen.util.coord_utils import get_linear_interpolated_value
-from pymatgen.serializers.json_coders import MSONable
+from pymatgen.serializers.json_coders import PMGSONable
 from monty.dev import requires
 
 try:
@@ -25,7 +27,7 @@ except ImportError:
     scipy = None
 
 
-class Dos(MSONable):
+class Dos(PMGSONable):
     """
     Basic DOS object. All other DOS objects are extended versions of this
     object.
@@ -93,7 +95,7 @@ class Dos(MSONable):
         from scipy.ndimage.filters import gaussian_filter1d
         smeared_dens = {}
         diff = [self.energies[i + 1] - self.energies[i]
-                for i in xrange(len(self.energies) - 1)]
+                for i in range(len(self.energies) - 1)]
         avgdiff = sum(diff) / len(diff)
         for spin, dens in self.densities.items():
             smeared_dens[spin] = gaussian_filter1d(dens, sigma / avgdiff)
@@ -151,9 +153,9 @@ class Dos(MSONable):
         if not abs_tol:
             tol = tol * tdos.sum() / tdos.shape[0]
         energies = self.energies
-        below_fermi = [i for i in xrange(len(energies))
+        below_fermi = [i for i in range(len(energies))
                        if energies[i] < self.efermi and tdos[i] > tol]
-        above_fermi = [i for i in xrange(len(energies))
+        above_fermi = [i for i in range(len(energies))
                        if energies[i] > self.efermi and tdos[i] > tol]
         vbm_start = max(below_fermi)
         cbm_start = min(above_fermi)
@@ -252,8 +254,7 @@ class Dos(MSONable):
                    {Spin.from_int(int(k)): v
                     for k, v in d["densities"].items()})
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         """
         Json-serializable dict representation of Dos.
         """
@@ -315,7 +316,7 @@ class CompleteDos(Dos):
         Returns:
             Dos containing summed orbital densities for site.
         """
-        site_dos = reduce(add_densities, self.pdos[site].values())
+        site_dos = six.moves.reduce(add_densities, self.pdos[site].values())
         return Dos(self.efermi, self.energies, site_dos)
 
     def get_site_spd_dos(self, site):
@@ -359,9 +360,9 @@ class CompleteDos(Dos):
                     elif orb in (Orbital.dx2, Orbital.dz2):
                         eg_dos.append(pdos)
         return {"t2g": Dos(self.efermi, self.energies,
-                           reduce(add_densities, t2g_dos)),
+                           six.moves.reduce(add_densities, t2g_dos)),
                 "e_g": Dos(self.efermi, self.energies,
-                           reduce(add_densities, eg_dos))}
+                           six.moves.reduce(add_densities, eg_dos))}
 
     def get_spd_dos(self):
         """
@@ -434,7 +435,7 @@ class CompleteDos(Dos):
         tdos = Dos.from_dict(d)
         struct = Structure.from_dict(d["structure"])
         pdoss = {}
-        for i in xrange(len(d["pdos"])):
+        for i in range(len(d["pdos"])):
             at = struct[i]
             orb_dos = {}
             for orb_str, odos in d["pdos"][i].items():
@@ -444,14 +445,13 @@ class CompleteDos(Dos):
             pdoss[at] = orb_dos
         return CompleteDos(struct, tdos, pdoss)
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         """
         Json-serializable dict representation of CompleteDos.
         """
         d = {"@module": self.__class__.__module__,
              "@class": self.__class__.__name__, "efermi": self.efermi,
-             "structure": self.structure.to_dict,
+             "structure": self.structure.as_dict(),
              "energies": list(self.energies),
              "densities": {str(spin): list(dens)
                            for spin, dens in self.densities.items()},
@@ -464,9 +464,9 @@ class CompleteDos(Dos):
                                                   for spin,
                                                   dens in pdos.items()}}
                 d["pdos"].append(dd)
-            d["atom_dos"] = {str(at): dos.to_dict for at,
+            d["atom_dos"] = {str(at): dos.as_dict() for at,
                              dos in self.get_element_dos().items()}
-            d["spd_dos"] = {str(orb): dos.to_dict for orb,
+            d["spd_dos"] = {str(orb): dos.as_dict() for orb,
                             dos in self.get_spd_dos().items()}
         return d
 
