@@ -16,17 +16,22 @@ from pymatgen.io.abinitio import myaml
 
 from pymatgen.io.abinitio import abiinspect
 from pymatgen.io.abinitio import events 
+import six
+from six.moves import map
+from six.moves import zip
 
 try:
     from pydispatch import dispatcher
 except ImportError:
     pass
 
-from monty.json import loadf 
+
+from monty.serialization import loadfn
+
 from pymatgen.core.design_patterns import Enum, AttrDict
 from pymatgen.util.io_utils import FileLock
 from pymatgen.util.string_utils import stream_has_colours, is_string, list_strings, WildCard
-from pymatgen.serializers.json_coders import MSONable, json_pretty_dump
+from pymatgen.serializers.json_coders import PMGSONable, json_pretty_dump
 from pymatgen.io.abinitio.utils import File, Directory, irdvars_for_ext, abi_splitext, abi_extensions, FilepathFixer, Condition
 
 from pymatgen.io.abinitio.qadapters import qadapter_class
@@ -61,7 +66,7 @@ def straceback():
     import traceback
     return traceback.format_exc()
 
-class TaskResults(dict, MSONable):
+class TaskResults(dict, PMGSONable):
     """
     Dictionary used to store the most important results produced by a Task.
     """
@@ -106,8 +111,7 @@ class TaskResults(dict, MSONable):
 
         return self.exceptions
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         d = {k: v for k,v in self.items()}
         d["@module"] = self.__class__.__module__
         d["@class"] = self.__class__.__name__
@@ -118,11 +122,11 @@ class TaskResults(dict, MSONable):
         return cls({k: v for k,v in d.items() if k not in ["@module", "@class",]})
 
     def json_dump(self, filename):
-        json_pretty_dump(self.to_dict, filename) 
+        json_pretty_dump(self.as_dict(), filename)
 
     @classmethod
     def json_load(cls, filename):
-        return cls.from_dict(loadf(filename))
+        return cls.from_dict(loadfn(filename))
 
 
 class ParalHintsError(Exception):
@@ -815,7 +819,7 @@ class Status(int):
             raise ValueError("Wrong string %s" % s)
 
 
-class Node(object):
+class Node(six.with_metaclass(abc.ABCMeta, object)):
     """
     Abstract base class defining the interface that must be 
     implemented by the nodes of the calculation.
@@ -823,7 +827,6 @@ class Node(object):
     Nodes are hashable and can be tested for equality
     (hash uses the node identifier, while eq uses workdir).
     """
-    __metaclass__ = abc.ABCMeta
 
     # Possible status of the node.
     S_INIT = Status(1)
@@ -1067,9 +1070,7 @@ class TaskRestartError(TaskError):
     """Exception raised while trying to restart the `Task`."""
 
 
-class Task(Node):
-    __metaclass__ = abc.ABCMeta
-
+class Task(six.with_metaclass(abc.ABCMeta, Node)):
     Error = TaskError
 
     # List of `AbinitEvent` subclasses that are tested in the not_converged method. 
@@ -1733,7 +1734,7 @@ class Task(Node):
             "task_name"      : self.name,
             "task_returncode": self.returncode,
             "task_status"    : self.status,
-            #"task_events"    : self.events.to_dict
+            #"task_events"    : self.events.as_dict()
         })
 
     def move(self, dest, is_abspath=False):
