@@ -7,6 +7,7 @@ runs.
 """
 
 from __future__ import division
+import six
 
 __author__ = "Alan Dozier"
 __credits__ = "Anubhav Jain, Shyue Ping Ong"
@@ -24,14 +25,13 @@ from monty.serialization import loadfn
 from pymatgen.io.feffio import FeffAtoms, FeffTags, FeffPot, Header
 
 
-class AbstractFeffInputSet(object):
+class AbstractFeffInputSet(six.with_metaclass(abc.ABCMeta, object)):
     """
     Abstract base class representing a set of Feff input parameters.
     The idea is that using a FeffInputSet, a complete set of input files
     (feffPOT,feffXANES, feffEXAFS, ATOMS, feff.inp)set_
     can be generated in an automated fashion for any structure.
     """
-    __metaclass__ = abc.ABCMeta
 
     @abc.abstractmethod
     def get_feff_atoms(self, structure, central_atom):
@@ -144,7 +144,7 @@ class AbstractFeffInputSet(object):
         feff_input = "\n\n".join(str(feff[f]) for f in ["HEADER", "PARAMETERS",
                                  "POTENTIALS", "ATOMS"])
 
-        for k, v in feff.iteritems():
+        for k, v in six.iteritems(feff):
             with open(os.path.join(output_dir, k), "w") as f:
                 f.write(str(v))
 
@@ -152,7 +152,7 @@ class AbstractFeffInputSet(object):
             f.write(feff_input)
         f.close()
 
-    def to_dict(self, structure, calc_type, source, central_atom,
+    def as_dict(self, structure, calc_type, source, central_atom,
                 comment=''):
         """Creates a feff.inp dictionary as a string"""
 
@@ -262,7 +262,7 @@ class FeffInputSet(AbstractFeffInputSet):
         for ns in section_names:
             for d in [self.xanes_settings, self.exafs_settings]:
                 output.append(ns)
-                for k, v in d.iteritems():
+                for k, v in six.iteritems(d):
                     output.append("%s = %s" % (k, str(v)))
                 output.append("")
 
