@@ -3,6 +3,8 @@ Classes for reading/manipulating/writing VASP ouput files.
 """
 
 from __future__ import division
+from six.moves import map
+from six.moves import zip
 
 __author__ = "Shyue Ping Ong, Geoffroy Hautier, Rickard Armiento, " + \
     "Vincent L Chevrier"
@@ -20,7 +22,7 @@ import re
 import math
 import itertools
 import warnings
-import StringIO
+from six.moves import cStringIO
 import logging
 from collections import defaultdict
 from xml.etree.cElementTree import iterparse
@@ -42,6 +44,7 @@ from pymatgen.core.lattice import Lattice
 from pymatgen.io.vaspio.vasp_input import Incar, Kpoints, Poscar
 from pymatgen.entries.computed_entries import \
     ComputedEntry, ComputedStructureEntry
+from pymatgen.serializers.json_coders import PMGSONable
 
 logger = logging.getLogger(__name__)
 
@@ -83,10 +86,10 @@ def _parse_v_parameters(val_type, val, filename, param_name):
         Parsed value.
     """
     if val_type == "logical":
-        val = map(lambda i: i == "T", val.split())
+        val = [i == "T" for i in val.split()]
     elif val_type == "int":
         try:
-            val = map(int, val.split())
+            val = [int(i) for i in val.split()]
         except ValueError:
             # Fix for stupid error in vasprun sometimes which displays
             # LDAUL/J as 2****
@@ -97,7 +100,7 @@ def _parse_v_parameters(val_type, val, filename, param_name):
         val = val.split()
     else:
         try:
-            val = map(float, val.split())
+            val = [float(i) for i in val.split()]
         except ValueError:
             # Fix for stupid error in vasprun sometimes which displays
             # MAGMOM as 2****
@@ -108,7 +111,7 @@ def _parse_v_parameters(val_type, val, filename, param_name):
 
 
 def _parse_varray(elem):
-    return [map(float, v.text.split()) for v in elem]
+    return [[float(i) for i in v.text.split()] for v in elem]
 
 
 def _parse_from_incar(filename, key):
@@ -127,7 +130,7 @@ def _parse_from_incar(filename, key):
     return None
 
 
-class Vasprun(object):
+class Vasprun(PMGSONable):
     """
     Vastly improved cElementTree-based parser for vasprun.xml files. Uses
     iterparse to support incremental parsing of large files.
@@ -291,7 +294,7 @@ class Vasprun(object):
                         steps[-1].split("</calculation>")[-1])
                 else:
                     to_parse = "{}<calculation>{}".format(preamble, to_parse)
-                self._parse(StringIO.StringIO(to_parse), parse_dos=parse_dos,
+                self._parse(cStringIO(to_parse), parse_dos=parse_dos,
                             parse_eigen=parse_eigen,
                             parse_projected_eigen=parse_projected_eigen)
             else:
@@ -411,7 +414,7 @@ class Vasprun(object):
         us = self.incar.get("LDAUU", self.parameters.get("LDAUU"))
         js = self.incar.get("LDAUJ", self.parameters.get("LDAUJ"))
         if len(us) == len(symbols):
-            return {symbols[i]: us[i] - js[i] for i in xrange(len(symbols))}
+            return {symbols[i]: us[i] - js[i] for i in range(len(symbols))}
         elif sum(us) == 0 and sum(js) == 0:
             return {}
         else:
@@ -534,10 +537,10 @@ class Vasprun(object):
 
         kpoints = [np.array(self.actual_kpoints[i])
                    for i in range(len(self.actual_kpoints))]
-        dict_eigen = self.to_dict['output']['eigenvalues']
+        dict_eigen = self.as_dict()['output']['eigenvalues']
         dict_p_eigen = {}
-        if 'projected_eigenvalues' in self.to_dict['output']:
-            dict_p_eigen = self.to_dict['output']['projected_eigenvalues']
+        if 'projected_eigenvalues' in self.as_dict()['output']:
+            dict_p_eigen = self.as_dict()['output']['projected_eigenvalues']
 
         p_eigenvals = {}
         if "1" in dict_eigen["0"] and "-1" in dict_eigen["0"] \
@@ -645,8 +648,7 @@ class Vasprun(object):
                     cbm_kpoint = k[0]
         return max(cbm - vbm, 0), cbm, vbm, vbm_kpoint == cbm_kpoint
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         """
         Json-serializable dict representation.
         """
@@ -654,8 +656,8 @@ class Vasprun(object):
              "has_vasp_completed": self.converged,
              "nsites": len(self.final_structure)}
         comp = self.final_structure.composition
-        d["unit_cell_formula"] = comp.to_dict
-        d["reduced_cell_formula"] = Composition(comp.reduced_formula).to_dict
+        d["unit_cell_formula"] = comp.as_dict()
+        d["reduced_cell_formula"] = Composition(comp.reduced_formula).as_dict()
         d["pretty_formula"] = comp.reduced_formula
         symbols = [s.split()[1] for s in self.potcar_symbols]
         symbols = [re.split("_", s)[0] for s in symbols]
@@ -666,7 +668,7 @@ class Vasprun(object):
             js = self.incar.get("LDAUJ", self.parameters.get("LDAUJ"))
             if len(us) == len(symbols):
                 d["hubbards"] = {symbols[i]: us[i] - js[i]
-                                 for i in xrange(len(symbols))}
+                                 for i in range(len(symbols))}
             else:
                 raise VaspParserError("Length of U value parameters and atomic"
                                       " symbols are mismatched.")
@@ -678,16 +680,16 @@ class Vasprun(object):
         d["run_type"] = self.run_type
 
         vin = {"incar": {k: v for k, v in self.incar.items()},
-               "crystal": self.initial_structure.to_dict,
-               "kpoints": self.kpoints.to_dict}
+               "crystal": self.initial_structure.as_dict(),
+               "kpoints": self.kpoints.as_dict()}
         actual_kpts = [{"abc": list(self.actual_kpoints[i]),
                         "weight": self.actual_kpoints_weights[i]}
-                       for i in xrange(len(self.actual_kpoints))]
+                       for i in range(len(self.actual_kpoints))]
         vin["kpoints"]["actual_points"] = actual_kpts
         vin["potcar"] = [s.split(" ")[1] for s in self.potcar_symbols]
         vin["potcar_type"] = [s.split(" ")[0] for s in self.potcar_symbols]
         vin["parameters"] = {k: v for k, v in self.parameters.items()}
-        vin["lattice_rec"] = self.lattice_rec.to_dict
+        vin["lattice_rec"] = self.lattice_rec.as_dict()
         d["input"] = vin
 
         nsites = len(self.final_structure)
@@ -695,7 +697,7 @@ class Vasprun(object):
         vout = {"ionic_steps": self.ionic_steps,
                 "final_energy": self.final_energy,
                 "final_energy_per_atom": self.final_energy / nsites,
-                "crystal": self.final_structure.to_dict,
+                "crystal": self.final_structure.as_dict(),
                 "efermi": self.efermi}
 
         if self.eigenvalues:
@@ -765,11 +767,11 @@ class Vasprun(object):
             name = v.attrib.get("name")
             toks = v.text.split()
             if name == "divisions":
-                k.kpts = [map(int, toks)]
+                k.kpts = [[int(i) for i in toks]]
             elif name == "usershift":
-                k.kpts_shift = map(float, toks)
+                k.kpts_shift = [float(i) for i in toks]
             elif name in {"genvec1", "genvec2", "genvec3", "shift"}:
-                setattr(k, name, map(float, toks))
+                setattr(k, name, [float(i) for i in toks])
         for va in elem.findall("varray"):
             name = va.attrib["name"]
             if name == "kpointlist":
@@ -825,7 +827,7 @@ class Vasprun(object):
                     Spin.down
                 data = np.array(_parse_varray(ss))
                 nrow, ncol = data.shape
-                for j in xrange(1, ncol):
+                for j in range(1, ncol):
                     pdos[Orbital.from_vasp_index(j - 1)][spin] = data[:, j]
             pdoss.append(pdos)
         elem.clear()
@@ -858,7 +860,7 @@ class Vasprun(object):
         return proj_eigen
 
 
-class Outcar(object):
+class Outcar(PMGSONable):
     """
     Parser for data in OUTCAR that is not available in Vasprun.xml
 
@@ -1018,7 +1020,7 @@ class Outcar(object):
 
             def er_bp(results, match):
                 results.er_bp[Spin.up] = np.array([float(match.group(i))
-                                                   for i in xrange(1, 4)]) / 2
+                                                   for i in range(1, 4)]) / 2
                 results.er_bp[Spin.down] = results.er_bp[Spin.up]
 
             search.append(["^ *e<r>_bp=\( *([-0-9.Ee+]*) *([-0-9.Ee+]*) "
@@ -1028,7 +1030,7 @@ class Outcar(object):
             # Spin cases
             def er_ev_up(results, match):
                 results.er_ev[Spin.up] = np.array([float(match.group(i))
-                                                   for i in xrange(1, 4)])
+                                                   for i in range(1, 4)])
                 results.context = Spin.up
 
             search.append(["^.*Spin component 1 *e<r>_ev=\( *([-0-9.Ee+]*) "
@@ -1056,7 +1058,7 @@ class Outcar(object):
 
             def er_bp_dn(results, match):
                 results.er_bp[Spin.down] = np.array([float(match.group(i))
-                                                     for i in xrange(1, 4)])
+                                                     for i in range(1, 4)])
             search.append(["^ *e<r>_bp=\( *([-0-9.Ee+]*) *([-0-9.Ee+]*) "
                            "*([-0-9.Ee+]*) *\)",
                            lambda results,
@@ -1065,7 +1067,7 @@ class Outcar(object):
             # Always present spin/non-spin
             def p_elc(results, match):
                 results.p_elc = np.array([float(match.group(i))
-                                          for i in xrange(1, 4)])
+                                          for i in range(1, 4)])
 
             search.append(["^.*Total electronic dipole moment: "
                            "*p\[elc\]=\( *([-0-9.Ee+]*) *([-0-9.Ee+]*) "
@@ -1073,7 +1075,7 @@ class Outcar(object):
 
             def p_ion(results, match):
                 results.p_ion = np.array([float(match.group(i))
-                                          for i in xrange(1, 4)])
+                                          for i in range(1, 4)])
 
             search.append(["^.*ionic dipole moment: "
                            "*p\[ion\]=\( *([-0-9.Ee+]*) *([-0-9.Ee+]*) "
@@ -1119,7 +1121,7 @@ class Outcar(object):
 
             def dielectric_data(results, match):
                 results.dielectric_tensor[results.dielectric_index, :] = \
-                    np.array([float(match.group(i)) for i in xrange(1, 4)])
+                    np.array([float(match.group(i)) for i in range(1, 4)])
                 results.dielectric_index += 1
 
             search.append(["^ *([-0-9.Ee+]+) +([-0-9.Ee+]+) +([-0-9.Ee+]+) *$",
@@ -1146,7 +1148,7 @@ class Outcar(object):
 
             def piezo_data(results, match):
                 results.piezo_tensor[results.piezo_index, :] = \
-                    np.array([float(match.group(i)) for i in xrange(1, 7)])
+                    np.array([float(match.group(i)) for i in range(1, 7)])
                 results.piezo_index += 1
 
             search.append(["^ *[xyz] +([-0-9.Ee+]+) +([-0-9.Ee+]+)" +
@@ -1181,7 +1183,7 @@ class Outcar(object):
 
             def born_data(results, match):
                 results.born[results.born_ion][int(match.group(1)) - 1, :] = \
-                    np.array([float(match.group(i)) for i in xrange(2, 5)])
+                    np.array([float(match.group(i)) for i in range(2, 5)])
 
             search.append(["^ *([1-3]+) +([-0-9.Ee+]+) +([-0-9.Ee+]+) "
                            "+([-0-9.Ee+]+)$",
@@ -1264,8 +1266,7 @@ class Outcar(object):
                         cl[iat][data[i]].append(float(data[i+1]))
         return cl
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         d = {"@module": self.__class__.__module__,
              "@class": self.__class__.__name__, "efermi": self.efermi,
              "run_stats": self.run_stats, "magnetization": self.magnetization,
@@ -1350,7 +1351,7 @@ class VolumetricData(object):
         ng = self.dim
         num_pts = ng[ind]
         lengths = self.structure.lattice.abc
-        return [i / num_pts * lengths[ind] for i in xrange(num_pts)]
+        return [i / num_pts * lengths[ind] for i in range(num_pts)]
 
     def __add__(self, other):
         return self.linear_add(other, 1.0)
@@ -1429,7 +1430,7 @@ class VolumetricData(object):
                         poscar = Poscar.from_string("\n".join(poscar_string))
                         poscar_read = True
                 elif not dim:
-                    dim = map(int, line.split())
+                    dim = [int(i) for i in line.split()]
                     ngrid_pts = dim[0] * dim[1] * dim[2]
                     dimline = line
                     read_dataset = True
@@ -1475,8 +1476,8 @@ class VolumetricData(object):
             lines = []
             count = 0
             f.write("{} {} {}\n".format(a[0], a[1], a[2]))
-            for (k, j, i) in itertools.product(xrange(a[2]), xrange(a[1]),
-                                               xrange(a[0])):
+            for (k, j, i) in itertools.product(list(range(a[2])), list(range(a[1])),
+                                               list(range(a[0]))):
                 lines.append("%0.11e" % self.data[data_type][i, j, k])
                 count += 1
                 if count % 5 == 0:
@@ -1513,7 +1514,7 @@ class VolumetricData(object):
         """
         #For non-spin-polarized runs, this is zero by definition.
         if not self.is_spin_polarized:
-            radii = [radius / nbins * (i + 1) for i in xrange(nbins)]
+            radii = [radius / nbins * (i + 1) for i in range(nbins)]
             data = np.zeros((nbins, 2))
             data[:, 0] = radii
             return data
@@ -1523,7 +1524,7 @@ class VolumetricData(object):
         if ind not in self._distance_matrix or\
                 self._distance_matrix[ind]["max_radius"] < radius:
             coords = []
-            for (x, y, z) in itertools.product(*[xrange(i) for i in a]):
+            for (x, y, z) in itertools.product(*[list(range(i)) for i in a]):
                 coords.append([x / a[0], y / a[1], z / a[2]])
             sites_dist = struct.lattice.get_points_in_sphere(
                 coords, struct[ind].coords, radius)
@@ -1545,7 +1546,7 @@ class VolumetricData(object):
         data = np.zeros((nbins, 2))
         data[:, 0] = edges[1:]
         data[:, 1] = [sum(hist[0:i + 1]) / self.ngridpts
-                      for i in xrange(nbins)]
+                      for i in range(nbins)]
         return data
 
     def get_average_along_axis(self, ind):
@@ -1669,7 +1670,7 @@ class Procar(object):
                     headers.pop(-1)
                 elif expr.match(l):
                     linedata = dataexpr.findall(l)
-                    num_data = map(float, linedata)
+                    num_data = [float(i) for i in linedata]
                     #Convert to zero-based indexing for atoms.
                     index = int(num_data.pop(0)) - 1
                     num_data.pop(-1)
@@ -1721,27 +1722,6 @@ class Procar(object):
 
         return dico
 
-    def get_d_occupation(self, atom_index):
-        """
-        .. deprecated:: v2.6.4
-
-            Use get_occpuation instead.
-
-        Returns the d occupation of a particular atom.
-
-        Args:
-            atom_index (int): Index of atom in PROCAR. It should be noted
-                that VASP uses 1-based indexing for atoms, but this is
-                converted to 0-based indexing in this parser to be
-                consistent with representation of structures in pymatgen.
-
-        Returns:
-            d-occupation of atom at atom_index.
-        """
-        warnings.warn("get_d_occupation has been deprecated. Use "
-                      "get_occupation instead.", DeprecationWarning)
-        return self.get_occupation(atom_index, 'd')
-
     def get_occupation(self, atom_index, orbital):
         """
         Returns the occupation for a particular orbital of a particular atom.
@@ -1840,7 +1820,7 @@ class Oszicar(object):
                 if m:
                     toks = m.group(1).split()
                     data = {header[i]: smart_convert(header[i], toks[i])
-                            for i in xrange(len(toks))}
+                            for i in range(len(toks))}
                     if toks[0] == "1":
                         electronic_steps.append([data])
                     else:
@@ -1878,7 +1858,7 @@ class Oszicar(object):
         ((4507.24605593, 143.824705755, -512.073149912, ...), ...)
         """
         all_energies = []
-        for i in xrange(len(self.electronic_steps)):
+        for i in range(len(self.electronic_steps)):
             energies = [step["E"] for step in self.electronic_steps[i]]
             energies.append(self.ionic_steps[i]["F"])
             all_energies.append(tuple(energies))
@@ -1892,8 +1872,7 @@ class Oszicar(object):
         """
         return self.ionic_steps[-1]["F"]
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         return {"electronic_steps": self.electronic_steps,
                 "ionic_steps": self.ionic_steps}
 
@@ -2021,7 +2000,7 @@ def get_adjusted_fermi_level(efermi, cbm, band_structure):
         a new adjusted fermi level
     """
     #make a working copy of band_structure
-    bs_working = BandStructureSymmLine.from_dict(band_structure.to_dict)
+    bs_working = BandStructureSymmLine.from_dict(band_structure.as_dict())
     if bs_working.is_metal():
         e = efermi
         while e < cbm:
