@@ -3,6 +3,7 @@ This module provides classes for predicting new structures from existing ones.
 """
 
 from __future__ import division
+from six.moves import zip
 
 __author__ = "Will Richards, Geoffroy Hautier"
 __copyright__ = "Copyright 2012, The Materials Project"
@@ -11,7 +12,12 @@ __maintainer__ = "Will Richards"
 __email__ = "wrichard@mit.edu"
 __date__ = "Aug 31, 2012"
 
-from pymatgen.serializers.json_coders import MSONable
+import itertools
+import logging
+from operator import mul
+import six
+
+from pymatgen.serializers.json_coders import PMGSONable
 from pymatgen.structure_prediction.substitution_probability \
     import SubstitutionProbability
 from pymatgen.transformations.standard_transformations \
@@ -19,12 +25,9 @@ from pymatgen.transformations.standard_transformations \
 from pymatgen.alchemy.transmuters import StandardTransmuter
 from pymatgen.alchemy.materials import TransformedStructure
 from pymatgen.alchemy.filters import RemoveDuplicatesFilter, RemoveExistingFilter
-import itertools
-import logging
-from operator import mul
 
 
-class Substitutor(MSONable):
+class Substitutor(PMGSONable):
     """
     This object uses a data mined ionic substitution approach to propose
     compounds likely to be stable. It relies on an algorithm presented in
@@ -63,16 +66,16 @@ class Substitutor(MSONable):
     def pred_from_structures(self, target_species, structures_list,
                              remove_duplicates=True, remove_existing=False):
         """
-        performs a structure prediction targeting compounds containing all of 
+        performs a structure prediction targeting compounds containing all of
         the target_species, based on a list of structure (those structures
         can for instance come from a database like the ICSD). It will return
         all the structures formed by ionic substitutions with a probability
         higher than the threshold
-        
+
         Notes:
         If the default probability model is used, input structures must
         be oxidation state decorated.
-        
+
         This method does not change the number of species in a structure. i.e
         if the number of target species is 3, only input structures containing
         3 species will be considered.
@@ -116,7 +119,7 @@ class Substitutor(MSONable):
                         self._threshold:
 
                     clean_subst = {els[i]: permut[i]
-                                   for i in xrange(0, len(els))
+                                   for i in range(0, len(els))
                                    if els[i] != permut[i]}
 
                     if len(clean_subst) == 0:
@@ -127,7 +130,7 @@ class Substitutor(MSONable):
                     if Substitutor._is_charge_balanced(
                             transf.apply_transformation(s['structure'])):
                         ts = TransformedStructure(
-                            s['structure'], [transf], 
+                            s['structure'], [transf],
                             history=[{"source": s['id']}],
                             other_parameters={
                                 'type': 'structure_prediction',
@@ -210,12 +213,12 @@ class Substitutor(MSONable):
         def _recurse(output_prob, output_species):
             best_case_prob = list(max_probabilities)
             best_case_prob[:len(output_prob)] = output_prob
-            if reduce(mul, best_case_prob) > self._threshold:
+            if six.moves.reduce(mul, best_case_prob) > self._threshold:
                 if len(output_species) == len(species_list):
                     odict = {
                         'substitutions':
                         dict(zip(species_list, output_species)),
-                        'probability': reduce(mul, best_case_prob)}
+                        'probability': six.moves.reduce(mul, best_case_prob)}
                     output.append(odict)
                     return
                 for sp in self._sp.species:
@@ -246,8 +249,7 @@ class Substitutor(MSONable):
                      'compositions found'.format(len(output)))
         return output
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         return {"name": self.__class__.__name__, "version": __version__,
                 "kwargs": self._kwargs, "threshold": self._threshold,
                 "@module": self.__class__.__module__,
