@@ -6,6 +6,8 @@ All transformations should inherit the AbstractTransformation ABC.
 """
 
 from __future__ import division
+from six.moves import map
+from six.moves import zip
 
 __author__ = "Shyue Ping Ong, Will Richards"
 __copyright__ = "Copyright 2011, The Materials Project"
@@ -19,6 +21,7 @@ import itertools
 import logging
 import time
 
+from pymatgen.symmetry.finder import SymmetryFinder
 from pymatgen.core.structure import Structure
 from pymatgen.transformations.transformation_abc import AbstractTransformation
 from pymatgen.analysis.ewald import EwaldSummation, EwaldMinimizer
@@ -69,8 +72,7 @@ class InsertSitesTransformation(AbstractTransformation):
     def is_one_to_many(self):
         return False
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         return {"name": self.__class__.__name__, "version": __version__,
                 "init_args": {"species": self._species, "coords": [list(x) for x in self._coords],
                               "coords_are_cartesian": self._cartesian,
@@ -116,8 +118,7 @@ class ReplaceSiteSpeciesTransformation(AbstractTransformation):
     def is_one_to_many(self):
         return False
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         return {
             "name": self.__class__.__name__, "version": __version__,
             "init_args": {"indices_species_map": self._indices_species_map},
@@ -155,8 +156,7 @@ class RemoveSitesTransformation(AbstractTransformation):
     def is_one_to_many(self):
         return False
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         return {"name": self.__class__.__name__, "version": __version__,
                 "init_args": {"indices_to_remove": self._indices},
                 "@module": self.__class__.__module__,
@@ -202,8 +202,7 @@ class TranslateSitesTransformation(AbstractTransformation):
     def is_one_to_many(self):
         return False
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         return {"name": self.__class__.__name__, "version": __version__,
                 "init_args": {"indices_to_move": self._indices,
                               "translation_vector": self._vector,
@@ -289,7 +288,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
 
         totalremovals = sum(num_remove_dict.values())
         removed = {k: 0 for k in num_remove_dict.keys()}
-        for i in xrange(totalremovals):
+        for i in range(totalremovals):
             maxindex = None
             maxe = float("-inf")
             maxindices = None
@@ -317,7 +316,6 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
     def complete_ordering(self, structure, num_remove_dict):
         self.logger.debug("Performing complete ordering...")
         all_structures = []
-        from pymatgen.symmetry.finder import SymmetryFinder
         symprec = 0.2
         s = SymmetryFinder(structure, symprec=symprec)
         self.logger.debug("Symmetry of structure is determined to be {}."
@@ -518,8 +516,7 @@ class PartialRemoveSitesTransformation(AbstractTransformation):
     def is_one_to_many(self):
         return True
 
-    @property
-    def to_dict(self):
+    def as_dict(self):
         return {"name": self.__class__.__name__, "version": __version__,
                 "init_args": {"indices": self._indices,
                               "fractions": self._fractions,
