@@ -5,6 +5,7 @@ numpy for performance.
 """
 
 from __future__ import division
+from six.moves import zip
 
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2011, The Materials Project"
@@ -15,7 +16,6 @@ __date__ = "Nov 27, 2011"
 
 import numpy as np
 import math
-from monty.dev import deprecated
 from pymatgen.core.lattice import Lattice
 
 #array size threshold for looping instead of broadcasting
@@ -197,29 +197,6 @@ def pbc_diff(fcoords1, fcoords2):
     return fdist - np.round(fdist)
 
 
-@deprecated(Lattice.get_all_distances)
-def pbc_all_distances(lattice, fcoords1, fcoords2):
-    """
-    Returns the distances between two lists of coordinates taking into
-    account periodic boundary conditions and the lattice. Note that this
-    computes an MxN array of distances (i.e. the distance between each
-    point in fcoords1 and every coordinate in fcoords2). This is
-    different functionality from pbc_diff.
-
-    Args:
-        lattice: lattice to use
-        fcoords1: First set of fractional coordinates. e.g., [0.5, 0.6,
-            0.7] or [[1.1, 1.2, 4.3], [0.5, 0.6, 0.7]]. It can be a single
-            coord or any array of coords.
-        fcoords2: Second set of fractional coordinates.
-
-    Returns:
-        2d array of cartesian distances. E.g the distance between
-        fcoords1[i] and fcoords2[j] is distances[i,j]
-    """
-    return lattice.get_all_distances(fcoords1, fcoords2)
-
-
 def pbc_shortest_vectors(lattice, fcoords1, fcoords2):
     """
     Returns the shortest vectors between two lists of coordinates taking into
@@ -269,7 +246,7 @@ def pbc_shortest_vectors(lattice, fcoords1, fcoords2):
         for i, c1 in enumerate(cart_f1):
             vectors = cart_f2[:, :, :] - c1[None, None, :]
             d_2 = np.sum(vectors ** 2, axis=-1)
-            shortest[i] = vectors[np.arange(len(vectors)), 
+            shortest[i] = vectors[np.arange(len(vectors)),
                                   np.argmin(d_2, axis=-1)]
         return shortest
 
@@ -330,37 +307,6 @@ def is_coord_subset_pbc(subset, superset, atol=1e-8):
     return np.all(any_close)
 
 
-@deprecated(Lattice.get_points_in_sphere)
-def get_points_in_sphere_pbc(lattice, frac_points, center, r):
-    """
-    Find all points within a sphere from the point taking into account
-    periodic boundary conditions. This includes sites in other periodic images.
-
-    Algorithm:
-
-    1. place sphere of radius r in crystal and determine minimum supercell
-       (parallelpiped) which would contain a sphere of radius r. for this
-       we need the projection of a_1 on a unit vector perpendicular
-       to a_2 & a_3 (i.e. the unit vector in the direction b_1) to
-       determine how many a_1"s it will take to contain the sphere.
-
-       Nxmax = r * length_of_b_1 / (2 Pi)
-
-    2. keep points falling within r.
-
-    Args:
-        lattice: The lattice/basis for the periodic boundary conditions.
-        frac_points: All points in the lattice in fractional coordinates.
-        center: Cartesian coordinates of center of sphere.
-        r: radius of sphere.
-
-    Returns:
-        [(fcoord, dist) ...] since most of the time, subsequent processing
-        requires the distance.
-    """
-    return lattice.get_points_in_sphere(frac_points, center, r)
-
-
 def lattice_points_in_supercell(supercell_matrix):
     """
     Returns the list of points on the original lattice contained in the
@@ -378,13 +324,14 @@ def lattice_points_in_supercell(supercell_matrix):
          [1, 1, 0], [1, 1, 1]])
     d_points = np.dot(diagonals, supercell_matrix)
 
-    minimax = np.array([np.min(d_points, axis=0), np.max(d_points, axis=0) + 1])
+    mins = np.min(d_points, axis=0)
+    maxes = np.max(d_points, axis=0) + 1
 
-    ar = np.arange(minimax[0, 0], minimax[1, 0])[:, None] * \
+    ar = np.arange(mins[0], maxes[0])[:, None] * \
          np.array([1, 0, 0])[None, :]
-    br = np.arange(minimax[0, 1], minimax[1, 1])[:, None] * \
+    br = np.arange(mins[1], maxes[1])[:, None] * \
          np.array([0, 1, 0])[None, :]
-    cr = np.arange(minimax[0, 2], minimax[1, 2])[:, None] * \
+    cr = np.arange(mins[2], maxes[2])[:, None] * \
          np.array([0, 0, 1])[None, :]
 
     all_points = ar[:, None, None] + br[None, :, None] + cr[None, None, :]
@@ -392,9 +339,9 @@ def lattice_points_in_supercell(supercell_matrix):
 
     frac_points = np.dot(all_points, np.linalg.inv(supercell_matrix))
 
-    tvects = frac_points[np.where(np.all(frac_points < 1 - 1e-10, axis=1)
-                                  & np.all(frac_points >= -1e-10, axis=1))]
-    assert len(tvects) == np.round(np.abs(np.linalg.det(supercell_matrix)))
+    tvects = frac_points[np.all(frac_points < 1 - 1e-10, axis=1)
+                         & np.all(frac_points >= -1e-10, axis=1)]
+    assert len(tvects) == round(abs(np.linalg.det(supercell_matrix)))
     return tvects
 
 
